@@ -3,7 +3,7 @@
  * Copyright 2004 _FF_ 
  * Francesco Fondelli <fondelli dot francesco, tiscali dot it>
  *
- * $Id: packet-icep.c 25601 2008-06-25 09:12:35Z guy $
+ * $Id: packet-icep.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1135,7 +1135,7 @@ static void dissect_icep_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 	
 	if (tree) {
 		
-		DBG0("got an icep msg, start analisys\n");
+		DBG0("got an icep msg, start analysis\n");
 		
                 /* create display subtree for the protocol */
 		
