@@ -2,7 +2,7 @@
  * Ronnie Sahlberg 2006
  * copied from packet-scsi.c
  *
- * $Id: packet-scsi-mmc.c 26091 2008-08-26 01:28:50Z wmeier $
+ * $Id: packet-scsi-mmc.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -525,8 +525,8 @@ static const value_string scsi_disc_info_disc_status_val[] = {
 static const value_string scsi_disc_info_bgfs_val[] = {
     {0x00,	"Blank or not CD-RW/DVD-RW"},
     {0x01,	"Background Format started but is not running nor complete"},
-    {0x02,	"Backgroung Format in progress"},
-    {0x03,	"Backgroung Format has completed"},
+    {0x02,	"Background Format in progress"},
+    {0x03,	"Background Format has completed"},
     {0,NULL}
 };
 
