@@ -7,7 +7,7 @@
  * IANA's full name is "TiVoConnect Beacon", where as TiVo's own
  * documentation calls this protocol "TiVoConnect Discovery Protocol".
  *
- * $Id: packet-tivoconnect.c 26281 2008-09-26 22:07:45Z wmeier $
+ * $Id: packet-tivoconnect.c 27882 2009-03-29 14:37:57Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -119,14 +119,14 @@ dissect_tivoconnect(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             gchar * value = NULL;
             gint fieldlen;
 
-            length = strlen(field) + 1;
+            length = (int)strlen(field) + 1;
 
             if ( !(value=strchr(field, '=')) ) {
                 /* bad packet: missing the field separator */
                 continue;
             }
             *value++='\0';
-            fieldlen=strlen(field)+1;
+            fieldlen=(int)strlen(field)+1;
 
             if ( g_ascii_strcasecmp(field,"tivoconnect") == 0 ) {
                 proto_tree_add_item(tivoconnect_tree,
