@@ -5,7 +5,7 @@
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: funnel.h 25979 2008-08-11 02:01:09Z lego $
+ * $Id: funnel.h 27627 2009-03-06 22:49:27Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,8 +50,8 @@ typedef struct _funnel_bt_t {
 	funnel_text_window_t* tw;
 	funnel_bt_cb_t func;
 	void* data;
-	void (*free)(void*);
-	void (*free_data)(void*);
+	void (*free_fcn)(void*);
+	void (*free_data_fcn)(void*);
 } funnel_bt_t;
 
 typedef struct _funnel_ops_t {
