@@ -1,7 +1,7 @@
 /* dlg_utils.c
  * Utilities to use when constructing dialogs
  *
- * $Id: dlg_utils.c 27630 2009-03-06 23:02:27Z wmeier $
+ * $Id: dlg_utils.c 30714 2009-10-26 17:28:02Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -151,7 +151,9 @@ dlg_button_row_new(const gchar *stock_id_first, ...)
         } else if (strcmp(stock_id, WIRESHARK_STOCK_SAVE_ALL) == 0) {
             save_all = stock_id;
         } else if (strcmp(stock_id, WIRESHARK_STOCK_DONT_SAVE) == 0) {
-        	dont_save = stock_id;
+            dont_save = stock_id;
+        } else if (strcmp(stock_id, WIRESHARK_STOCK_QUIT_DONT_SAVE) == 0) {
+       	    dont_save = stock_id;
         } else if (strcmp(stock_id, GTK_STOCK_CANCEL) == 0) {
             cancel = stock_id;
         } else if (strcmp(stock_id, GTK_STOCK_CLOSE) == 0) {
@@ -418,9 +420,16 @@ dlg_window_new(const gchar *title)
    * to capture, and might also simplify the job of having the GUI main
    * loop wait both for user input and packet arrival.
    */
+  /*
+   * On Windows, making the dialogs transient to top_level behaves strangely.
+   * It is not possible any more to bring the top level window to front easily.
+   * So we don't do this on Windows.
+   */
+#ifndef _WIN32
   if (top_level) {
     gtk_window_set_transient_for(GTK_WINDOW(win), GTK_WINDOW(top_level));
   }
+#endif /*_WIN32*/
 
   return win;
 }
