@@ -1,7 +1,7 @@
 /* range_utils.c
  * Packet range routines (save, print, ...) for GTK things
  *
- * $Id: range_utils.c 20522 2007-01-22 00:20:33Z sfisher $
+ * $Id: range_utils.c 25634 2008-06-29 15:51:43Z wmeier $
  *
  * Ulf Lamping <ulf.lamping@web.de>
  *
@@ -30,14 +30,13 @@
 
 #include <gtk/gtk.h>
 
-#include "globals.h"
+#include "../globals.h"
+#include "../simple_dialog.h"
+#include "../packet-range.h"
 
-#include "packet-range.h"
-#include "gui_utils.h"
-#include "dlg_utils.h"
-#include "compat_macros.h"
-#include "simple_dialog.h"
-#include "range_utils.h"
+#include "gtk/gui_utils.h"
+#include "gtk/dlg_utils.h"
+#include "gtk/range_utils.h"
 
 
 #define RANGE_VALUES_KEY                "range_values"
@@ -97,10 +96,10 @@ range_update_dynamics(gpointer data)
   gchar         label_text[100];
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);
 
   
-  range_displayed_bt = OBJECT_GET_DATA(data, RANGE_DISPLAYED_BT_KEY);
+  range_displayed_bt = g_object_get_data(G_OBJECT(data), RANGE_DISPLAYED_BT_KEY);
   filtered_active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(range_displayed_bt));
 
   /* Enable saving only the displayed packets only if there *are*
@@ -111,42 +110,42 @@ range_update_dynamics(gpointer data)
     /* If saving the displayed packets is selected, select saving the
        captured packets. */
     filtered_active = FALSE;
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(OBJECT_GET_DATA(data, RANGE_SELECT_ALL_KEY)), FALSE);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g_object_get_data(G_OBJECT(data), RANGE_SELECT_ALL_KEY)), FALSE);
     gtk_widget_set_sensitive(range_displayed_bt, FALSE);
   }
 
-  gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_ALL_C_KEY), !filtered_active);
+  gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_ALL_C_KEY), !filtered_active);
   g_snprintf(label_text, sizeof(label_text), "%u", cfile.count);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_ALL_C_KEY)), label_text);
-  gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_ALL_D_KEY), filtered_active);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_ALL_C_KEY)), label_text);
+  gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_ALL_D_KEY), filtered_active);
   g_snprintf(label_text, sizeof(label_text), "%u", range->displayed_cnt);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_ALL_D_KEY)), label_text);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_ALL_D_KEY)), label_text);
 
   /* Enable saving the currently-selected packet only if there *is* a
      currently-selected packet. */
   selected_num = (cfile.current_frame) ? cfile.current_frame->num : 0;
   can_select = (selected_num != 0);
   if (can_select) {
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_CURR_KEY), TRUE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_CURR_C_KEY), !filtered_active);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_CURR_D_KEY), filtered_active);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_CURR_KEY), TRUE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_CURR_C_KEY), !filtered_active);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_CURR_D_KEY), filtered_active);
   } else {
     /* If "save selected packet" is selected, select "save all packets". */
     if (range->process == range_process_selected) {
       range->process = range_process_all;
-      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(OBJECT_GET_DATA(data, RANGE_SELECT_ALL_KEY)), TRUE);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g_object_get_data(G_OBJECT(data), RANGE_SELECT_ALL_KEY)), TRUE);
     }
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_CURR_KEY), FALSE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_CURR_C_KEY), FALSE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_CURR_D_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_CURR_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_CURR_C_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_CURR_D_KEY), FALSE);
   }
   /* XXX: how to update the radio button label but keep the mnemonic? */
 /*g_snprintf(label_text, sizeof(label_text), "_Selected packet #%u only", selected_num);
   gtk_label_set_text(GTK_LABEL(GTK_BIN(select_curr_rb)->child), label_text);*/
   g_snprintf(label_text, sizeof(label_text), "%u", selected_num ? 1 : 0);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_CURR_C_KEY)), label_text);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_CURR_C_KEY)), label_text);
   g_snprintf(label_text, sizeof(label_text), "%u", selected_num ? 1 : 0);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_CURR_D_KEY)), label_text);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_CURR_D_KEY)), label_text);
 
   /* Enable the buttons for saving marked packets only if there *are*
      marked packets. */
@@ -155,24 +154,24 @@ range_update_dynamics(gpointer data)
   else
     can_select = (cfile.marked_count > 0);
   if (can_select) {
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_KEY), TRUE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_C_KEY), !filtered_active);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_D_KEY), filtered_active);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_KEY), TRUE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_C_KEY), !filtered_active);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_D_KEY), filtered_active);
   }
   else {
     /* If "save marked packet" is selected, select "save all packets". */
     if (range->process == range_process_marked) {
       range->process = range_process_all;
-      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(OBJECT_GET_DATA(data, RANGE_SELECT_ALL_KEY)), TRUE);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g_object_get_data(G_OBJECT(data), RANGE_SELECT_ALL_KEY)), TRUE);
     }
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_KEY), FALSE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_C_KEY), FALSE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_D_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_C_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_D_KEY), FALSE);
   }
   g_snprintf(label_text, sizeof(label_text), "%u", cfile.marked_count);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_C_KEY)), label_text);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_C_KEY)), label_text);
   g_snprintf(label_text, sizeof(label_text), "%u", range->displayed_marked_cnt);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_D_KEY)), label_text);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_D_KEY)), label_text);
 
   /* Enable the buttons for saving the range of marked packets only if
      there *is* a range of marked packets. */
@@ -181,33 +180,33 @@ range_update_dynamics(gpointer data)
   else
     can_select = (range->mark_range_cnt != 0);
   if (can_select) {
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_RANGE_KEY), TRUE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_RANGE_C_KEY), !filtered_active);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_RANGE_D_KEY), filtered_active);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_RANGE_KEY), TRUE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_RANGE_C_KEY), !filtered_active);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_RANGE_D_KEY), filtered_active);
   }
   else {
     /* If "save range between first and last marked packet" is selected,
        select "save all packets". */
     if (range->process == range_process_marked_range) {
       range->process = range_process_all;
-      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(OBJECT_GET_DATA(data, RANGE_SELECT_ALL_KEY)), TRUE);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g_object_get_data(G_OBJECT(data), RANGE_SELECT_ALL_KEY)), TRUE);
     }
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_RANGE_KEY), FALSE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_RANGE_C_KEY), FALSE);
-    gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_RANGE_D_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_RANGE_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_RANGE_C_KEY), FALSE);
+    gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_RANGE_D_KEY), FALSE);
   }
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_RANGE_C_KEY)), label_text);
-  g_snprintf(label_text, sizeof(label_text), "%u", range->displayed_mark_range_cnt);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_MARKED_RANGE_D_KEY)), label_text);
   g_snprintf(label_text, sizeof(label_text), "%u", range->mark_range_cnt);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_RANGE_C_KEY)), label_text);
+  g_snprintf(label_text, sizeof(label_text), "%u", range->displayed_mark_range_cnt);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_MARKED_RANGE_D_KEY)), label_text);
 
-  gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_USER_KEY), TRUE);
-  gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_USER_C_KEY), !filtered_active);
-  gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_USER_D_KEY), filtered_active);
+  gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_KEY), TRUE);
+  gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_C_KEY), !filtered_active);
+  gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_D_KEY), filtered_active);
   g_snprintf(label_text, sizeof(label_text), "%u", range->user_range_cnt);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_USER_C_KEY)), label_text);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_C_KEY)), label_text);
   g_snprintf(label_text, sizeof(label_text), "%u", range->displayed_user_range_cnt);
-  gtk_label_set_text(GTK_LABEL(OBJECT_GET_DATA(data, RANGE_SELECT_USER_D_KEY)), label_text);
+  gtk_label_set_text(GTK_LABEL(g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_D_KEY)), label_text);
 }
 
 
@@ -218,16 +217,16 @@ toggle_captured_cb(GtkWidget *widget, gpointer data)
   packet_range_t *range;
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);
 
   /* is the button now active? */
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget))) {
     /* They changed the state of the "captured" button. */
     range->process_filtered = FALSE;
 
-    bt = OBJECT_GET_DATA(data, RANGE_CAPTURED_BT_KEY);
+    bt = g_object_get_data(G_OBJECT(data), RANGE_CAPTURED_BT_KEY);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bt), TRUE);
-    bt = OBJECT_GET_DATA(data, RANGE_DISPLAYED_BT_KEY);
+    bt = g_object_get_data(G_OBJECT(data), RANGE_DISPLAYED_BT_KEY);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bt), FALSE);
 
     range_update_dynamics(data);
@@ -241,14 +240,14 @@ toggle_filtered_cb(GtkWidget *widget, gpointer data)
   packet_range_t *range;
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);
   
   /* is the button now active? */
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget))) {
     range->process_filtered = TRUE;
-    bt = OBJECT_GET_DATA(data, RANGE_CAPTURED_BT_KEY);
+    bt = g_object_get_data(G_OBJECT(data), RANGE_CAPTURED_BT_KEY);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bt), FALSE);
-    bt = OBJECT_GET_DATA(data, RANGE_DISPLAYED_BT_KEY);
+    bt = g_object_get_data(G_OBJECT(data), RANGE_DISPLAYED_BT_KEY);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bt), TRUE);
     
     range_update_dynamics(data);
@@ -261,7 +260,7 @@ toggle_select_all(GtkWidget *widget, gpointer data)
   packet_range_t *range;
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);
   
   /* is the button now active? */
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget))) {
@@ -276,7 +275,7 @@ toggle_select_selected(GtkWidget *widget, gpointer data)
   packet_range_t *range;
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);
   
   /* is the button now active? */
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget))) {
@@ -291,7 +290,7 @@ toggle_select_marked_only(GtkWidget *widget, gpointer data)
   packet_range_t *range;
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);
   
   /* is the button now active? */
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget))) {
@@ -306,7 +305,7 @@ toggle_select_marked_range(GtkWidget *widget, gpointer data)
   packet_range_t *range;
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);
   
   /* is the button now active? */
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget))) {
@@ -321,7 +320,7 @@ toggle_select_user_range(GtkWidget *widget, gpointer data)
   packet_range_t *range;
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);
   
   /* is the button now active? */
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget))) {
@@ -330,11 +329,11 @@ toggle_select_user_range(GtkWidget *widget, gpointer data)
   }
 	
   /* Make the entry widget sensitive or insensitive */
-  gtk_widget_set_sensitive(OBJECT_GET_DATA(data, RANGE_SELECT_USER_ENTRY_KEY), range->process == range_process_user_range);
+  gtk_widget_set_sensitive(g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_ENTRY_KEY), range->process == range_process_user_range);
 
   /* When selecting user specified range, then focus on the entry */
   if (range->process == range_process_user_range)
-      gtk_widget_grab_focus(OBJECT_GET_DATA(data, RANGE_SELECT_USER_ENTRY_KEY));
+    gtk_widget_grab_focus(g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_ENTRY_KEY));
 
 }
 
@@ -347,10 +346,10 @@ range_entry(GtkWidget *widget _U_, gpointer data)
   packet_range_t *range;
 
 
-  range = OBJECT_GET_DATA(data, RANGE_VALUES_KEY);  
-  entry = OBJECT_GET_DATA(data, RANGE_SELECT_USER_ENTRY_KEY);
+  range = g_object_get_data(G_OBJECT(data), RANGE_VALUES_KEY);  
+  entry = g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_ENTRY_KEY);
 
-  gtk_toggle_button_set_active(OBJECT_GET_DATA(data, RANGE_SELECT_USER_KEY), TRUE);
+  gtk_toggle_button_set_active(g_object_get_data(G_OBJECT(data), RANGE_SELECT_USER_KEY), TRUE);
   entry_text = gtk_entry_get_text (GTK_ENTRY (entry));
   packet_range_convert_str(range, entry_text);
   range_update_dynamics(data);
@@ -377,11 +376,8 @@ range_entry_in_event(GtkWidget *widget _U_, GdkEventFocus *event _U_, gpointer u
 
 
 /* create a new range "widget" */
-GtkWidget *range_new(packet_range_t *range
-#if GTK_MAJOR_VERSION < 2
-, GtkAccelGroup *accel_group
-#endif
-) {
+GtkWidget *range_new(packet_range_t *range)
+{
   GtkWidget     *range_tb;
   GtkWidget     *captured_bt;
   GtkWidget     *displayed_bt;
@@ -411,27 +407,27 @@ GtkWidget *range_new(packet_range_t *range
 
   /* range table */
   range_tb = gtk_table_new(7, 3, FALSE);
-  gtk_container_border_width(GTK_CONTAINER(range_tb), 5);
+  gtk_container_set_border_width(GTK_CONTAINER(range_tb), 5);
 
   /* captured button */
-  captured_bt = TOGGLE_BUTTON_NEW_WITH_MNEMONIC("_Captured", accel_group);
+  captured_bt = gtk_toggle_button_new_with_mnemonic("_Captured");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), captured_bt, 1, 2, 0, 1);
-  SIGNAL_CONNECT(captured_bt, "toggled", toggle_captured_cb, range_tb);
+  g_signal_connect(captured_bt, "toggled", G_CALLBACK(toggle_captured_cb), range_tb);
   gtk_tooltips_set_tip (tooltips,captured_bt,("Process all the below chosen packets"), NULL);
 
   /* displayed button */
-  displayed_bt = TOGGLE_BUTTON_NEW_WITH_MNEMONIC("_Displayed", accel_group);
+  displayed_bt = gtk_toggle_button_new_with_mnemonic("_Displayed");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), displayed_bt, 2, 3, 0, 1);
-  SIGNAL_CONNECT(displayed_bt, "toggled", toggle_filtered_cb, range_tb);
+  g_signal_connect(displayed_bt, "toggled", G_CALLBACK(toggle_filtered_cb), range_tb);
   gtk_tooltips_set_tip (tooltips,displayed_bt,("Process only the below chosen packets, which also passes the current display filter"), NULL);
 
 
   /* Process all packets */
-  select_all_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(NULL, "_All packets", accel_group);
+  select_all_rb = gtk_radio_button_new_with_mnemonic_from_widget(NULL, "_All packets");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_all_rb, 0, 1, 1, 2);
   gtk_tooltips_set_tip (tooltips, select_all_rb, 
       ("Process all packets"), NULL);
-  SIGNAL_CONNECT(select_all_rb, "toggled", toggle_select_all, range_tb);
+  g_signal_connect(select_all_rb, "toggled", G_CALLBACK(toggle_select_all), range_tb);
 
   select_all_c_lb = gtk_label_new("?");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_all_c_lb, 1, 2, 1, 2);
@@ -440,10 +436,10 @@ GtkWidget *range_new(packet_range_t *range
 
 
   /* Process currently selected */
-  select_curr_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(select_all_rb, "_Selected packet only", accel_group);
+  select_curr_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(select_all_rb), "_Selected packet only");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_curr_rb, 0, 1, 2, 3);
   gtk_tooltips_set_tip (tooltips, select_curr_rb, ("Process the currently selected packet only"), NULL);
-  SIGNAL_CONNECT(select_curr_rb, "toggled", toggle_select_selected, range_tb);
+  g_signal_connect(select_curr_rb, "toggled", G_CALLBACK(toggle_select_selected), range_tb);
 
   select_curr_c_lb = gtk_label_new("?");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_curr_c_lb, 1, 2, 2, 3);
@@ -452,10 +448,10 @@ GtkWidget *range_new(packet_range_t *range
 
 
   /* Process marked packets */
-  select_marked_only_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(select_all_rb, "_Marked packets only", accel_group);
+  select_marked_only_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(select_all_rb), "_Marked packets only");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_marked_only_rb, 0, 1, 3, 4);
   gtk_tooltips_set_tip (tooltips, select_marked_only_rb, ("Process marked packets only"), NULL);
-  SIGNAL_CONNECT(select_marked_only_rb, "toggled", toggle_select_marked_only, range_tb);
+  g_signal_connect(select_marked_only_rb, "toggled", G_CALLBACK(toggle_select_marked_only), range_tb);
 
   select_marked_only_c_lb = gtk_label_new("?");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_marked_only_c_lb, 1, 2, 3, 4);
@@ -464,10 +460,10 @@ GtkWidget *range_new(packet_range_t *range
 
 
   /* Process packet range between first and last packet */
-  select_marked_range_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(select_all_rb, "From first _to last marked packet", accel_group);
+  select_marked_range_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(select_all_rb), "From first _to last marked packet");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_marked_range_rb, 0, 1, 4, 5);
   gtk_tooltips_set_tip (tooltips,select_marked_range_rb,("Process all packets between the first and last marker"), NULL);
-  SIGNAL_CONNECT(select_marked_range_rb, "toggled", toggle_select_marked_range, range_tb);
+  g_signal_connect(select_marked_range_rb, "toggled", G_CALLBACK(toggle_select_marked_range), range_tb);
 
   select_marked_range_c_lb = gtk_label_new("?");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_marked_range_c_lb, 1, 2, 4, 5);
@@ -476,10 +472,10 @@ GtkWidget *range_new(packet_range_t *range
 
 
   /* Process a user specified provided packet range : -10,30,40-70,80- */
-  select_user_range_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(select_all_rb, "Specify a packet _range:", accel_group);
+  select_user_range_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(select_all_rb), "Specify a packet _range:");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_user_range_rb, 0, 1, 5, 6);
   gtk_tooltips_set_tip (tooltips,select_user_range_rb,("Process a specified packet range"), NULL);
-  SIGNAL_CONNECT(select_user_range_rb, "toggled", toggle_select_user_range, range_tb);
+  g_signal_connect(select_user_range_rb, "toggled", G_CALLBACK(toggle_select_user_range), range_tb);
 
   select_user_range_c_lb = gtk_label_new("?");
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_user_range_c_lb, 1, 2, 5, 6);
@@ -493,35 +489,35 @@ GtkWidget *range_new(packet_range_t *range
   gtk_table_attach_defaults(GTK_TABLE(range_tb), select_user_range_entry, 0, 1, 6, 7);
   gtk_tooltips_set_tip (tooltips,select_user_range_entry, 
 	("Specify a range of packet numbers :     \nExample :  1-10,18,25-100,332-"), NULL);
-  SIGNAL_CONNECT(select_user_range_entry,"changed", range_entry, range_tb);
-  SIGNAL_CONNECT(select_user_range_entry,"activate", range_entry_in_event, range_tb);
+  g_signal_connect(select_user_range_entry,"changed", G_CALLBACK(range_entry), range_tb);
+  g_signal_connect(select_user_range_entry,"activate", G_CALLBACK(range_entry_in_event), range_tb);
 
 
   gtk_widget_show_all(range_tb);
 
 
-  OBJECT_SET_DATA(range_tb, RANGE_VALUES_KEY,               range);
-  OBJECT_SET_DATA(range_tb, RANGE_CAPTURED_BT_KEY,          captured_bt);
-  OBJECT_SET_DATA(range_tb, RANGE_DISPLAYED_BT_KEY,         displayed_bt);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_VALUES_KEY,               range);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_CAPTURED_BT_KEY,          captured_bt);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_DISPLAYED_BT_KEY,         displayed_bt);
 
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_ALL_KEY,           select_all_rb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_ALL_C_KEY,         select_all_c_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_ALL_D_KEY,         select_all_d_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_ALL_KEY,           select_all_rb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_ALL_C_KEY,         select_all_c_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_ALL_D_KEY,         select_all_d_lb);
 
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_CURR_KEY,          select_curr_rb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_CURR_C_KEY,        select_curr_c_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_CURR_D_KEY,        select_curr_d_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_CURR_D_KEY,        select_curr_d_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_MARKED_KEY,        select_marked_only_rb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_MARKED_C_KEY,      select_marked_only_c_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_MARKED_D_KEY,      select_marked_only_d_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_MARKED_RANGE_KEY,  select_marked_range_rb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_MARKED_RANGE_C_KEY,select_marked_range_c_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_MARKED_RANGE_D_KEY,select_marked_range_d_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_USER_KEY,          select_user_range_rb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_USER_C_KEY,        select_user_range_c_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_USER_D_KEY,        select_user_range_d_lb);
-  OBJECT_SET_DATA(range_tb, RANGE_SELECT_USER_ENTRY_KEY,    select_user_range_entry);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_CURR_KEY,          select_curr_rb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_CURR_C_KEY,        select_curr_c_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_CURR_D_KEY,        select_curr_d_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_CURR_D_KEY,        select_curr_d_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_MARKED_KEY,        select_marked_only_rb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_MARKED_C_KEY,      select_marked_only_c_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_MARKED_D_KEY,      select_marked_only_d_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_MARKED_RANGE_KEY,  select_marked_range_rb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_MARKED_RANGE_C_KEY,select_marked_range_c_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_MARKED_RANGE_D_KEY,select_marked_range_d_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_USER_KEY,          select_user_range_rb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_USER_C_KEY,        select_user_range_c_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_USER_D_KEY,        select_user_range_d_lb);
+  g_object_set_data(G_OBJECT(range_tb), RANGE_SELECT_USER_ENTRY_KEY,    select_user_range_entry);
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(captured_bt), !range->process_filtered);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayed_bt), range->process_filtered);
