@@ -1,6 +1,6 @@
 /* Combine multiple dump files, either by appending or by merging by timestamp
  *
- * $Id: merge.c 23764 2007-12-05 10:24:37Z guy $
+ * $Id: merge.c 28055 2009-04-15 16:02:35Z gerald $
  *
  * Written by Scott Renfro <scott@renfro.org> based on
  * editcap by Richard Sharpe and Guy Harris
@@ -157,7 +157,7 @@ merge_read_packet(int in_file_count, merge_in_file_t in_files[], int *err,
 {
   int i;
   int ei = -1;
-  struct wtap_nstime tv = {(time_t)LONG_MAX, INT_MAX};
+  struct wtap_nstime tv = { sizeof(time_t) > sizeof(int) ? LONG_MAX : INT_MAX, INT_MAX };
   struct wtap_pkthdr *phdr;
 
   /*
