@@ -1,6 +1,6 @@
 /* strerror.c
  *
- * $Id: strerror.c 18197 2006-05-21 05:12:17Z sahlberg $
+ * $Id: strerror.c 24258 2008-02-03 15:38:20Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,7 +35,7 @@ strerror(int errnum)
 	static char errbuf[5+1+11+1];	/* "Error %d" */
 
 	if (errnum < 0 || errnum >= sys_nerr) {
-		sprintf(errbuf, "Error %d", errnum);
+		g_snprintf(errbuf, 18, "Error %d", errnum);
 		return errbuf;
 	} else
 		return sys_errlist[errnum];
